@@ -6,7 +6,7 @@ def r_smooth_loop(input_dir, trial_type):
     if trial_type == 'cat_alone':
 
         variables = [
-            'x', 'y', 'cat_distance', 'velocity', 'acceleration'
+            'x_cat', 'y_cat', 'cat_distance', 'velocity', 'acceleration'
         ]
 
     elif trial_type == 'with_owner':
@@ -16,7 +16,7 @@ def r_smooth_loop(input_dir, trial_type):
             'velocity', 'acceleration'
         ]
 
-    with open('smooth.r', 'w') as f:
+    with open(f'smooth_{trial_type}.r', 'w') as f:
 
         # Load packages
 
@@ -44,4 +44,4 @@ def r_smooth_loop(input_dir, trial_type):
                        + ' <- ' + i + '_loess05', file=f)
 
             print('write.csv(df, "' + file[:-4] +
-                  '_smoothed.csv" , row.names = FALSE)', file=f)
+                  '.csv" , row.names = FALSE)', file=f)
